@@ -1,5 +1,6 @@
 """Module for caching data in sql db"""
 
+from copy import deepcopy
 import sqlite3
 import os.path
 import os
@@ -8,6 +9,7 @@ from .tucache import TuCache
 from .tuiter import SqlIter, TuIter
 from .helper import get_datetime, start_end_from_tdelta
 
+
 CREATE_HISTORY_META = '''
 create table historymeta(
     unit text, 
@@ -287,6 +289,7 @@ def sql_item_to_history_item(obj):
 class SqlInsertIter:
     """iterator for tucache data"""
     def __init__(self, table, sqliter, meta=None, _db=None):
+        assert _db is not None
         print("SqlInsertIter __init__ has sqliter:",sqliter)
         self.sqliter = sqliter
         self.iter_started = False
@@ -344,14 +347,16 @@ class SqlInsertIter:
             raise sqlite3.IntegrityError from exc1
 class SqlCache:
     """Sql cache can cache trackunit data in Sqlite DB"""
-    def __init__(self,auth=None,_dir=None,db_file="webdb.db",upstream_cache=None):
-        create_tables = not os.path.isfile(db_file)
-        self.web_db_path = db_file
+    def __init__(self,**kwargs):
+        self.web_db_path = kwargs.get('db_path','sqlcache.sqlite')
+        create_tables = not os.path.isfile(self.web_db_path)
         self._db = sqlite3.connect(self.web_db_path)
-        self.cache = upstream_cache
+        assert self._db is not None
+        cache1_kwargs = deepcopy(kwargs)
+        cache1_kwargs['dont_cache_data'] = kwargs.get('sql_cache1_dont_cache_data',True)
+        self.cache1 = kwargs.get('sql_cache1',TuCache(**cache1_kwargs))
+        self.cache2 = kwargs.get('sql_cache2',TuCache(**kwargs))
         self.tdelta_end = None
-        if self.cache is None:
-            self.cache = TuCache(auth,_dir,verbose=True)
         if create_tables:
             cur = self._db.cursor()
             cur.execute(CREATE_HISTORY_TABLE)
@@ -367,6 +372,9 @@ class SqlCache:
             self._db.close()
             os.remove(self.web_db_path)
             self._db = None
+    async def get_unitlist(self):
+        """returns a list of vehicles"""
+        return await self.cache2.get_unitlist()
     # pylint: disable=too-many-arguments
     def get_general_upstream(self, table, veh_id, start_ts, end_ts, previter=None):
         """gets errors from upstream cache"""
@@ -380,11 +388,11 @@ class SqlCache:
         end = datetime.fromtimestamp(end_ts/1000.0)
 
         if table == "error":
-            int_data_iter, _len = self.cache.get_faults_timedelta(veh_id,start,end,None)
+            int_data_iter, _len = self.cache1.get_faults_timedelta(veh_id,start,end,None)
         elif table == "history":
-            int_data_iter, _len = self.cache.get_history_timedelta(veh_id,start,end,None)
+            int_data_iter, _len = self.cache1.get_history_timedelta(veh_id,start,end,None)
         elif table == "candata":
-            int_data_iter, _len = self.cache.get_candata_timedelta(veh_id,start,end,None)
+            int_data_iter, _len = self.cache1.get_candata_timedelta(veh_id,start,end,None)
         else:
             raise Exception("Not Implemented")
 
