@@ -10,8 +10,8 @@ URL_BASE = r'https://api.trackunit.com/public/'
 
 class TuCache:
     """tucache class"""
-    def __init__(self,auth=None,_dir=None,verbose=False):
-        self.cache = WebCache(auth=auth,_dir=_dir,verbose=verbose)
+    def __init__(self,**kwargs):
+        self.cache = WebCache(**kwargs)
         self.req_period = 30
         self.tdelta_end = None
     def clean(self):
@@ -27,6 +27,9 @@ class TuCache:
         if self.cache.dont_read_files and len(data) == 0:
             return []
         return data.get('list')
+    async def get_unitlist(self):
+        """returns a list of vehicles"""
+        return await self.get_url('Unit')
     def general_daydiff_get(self,furl,meta,previter=None):
         """returns data for timedependant requests for a given daydelta"""
         tdelta = meta["tdelta"]
@@ -66,7 +69,7 @@ class TuCache:
         meta["id"] = veh_id
         meta["start"] = start
         meta["end"] = end
-        return self.general_daydiff_get(lambda t1,t2: \
+        return self.general_time_range_get(lambda t1,t2: \
             'Report/UnitHistory?unitId='+veh_id+'&from='+t1+'.0000001Z&to='+t2+'.0000000Z',\
                 meta,previter)
     def get_candata(self,veh_id,tdelta=None,previter=None):
@@ -83,7 +86,7 @@ class TuCache:
         meta["id"] = veh_id
         meta["start"] = start
         meta["end"] = end
-        return self.general_daydiff_get(lambda t1,t2: \
+        return self.general_time_range_get(lambda t1,t2: \
             'Report/UnitExtendedInfo?Id='+veh_id+'&from='+t1+'.0000001Z&to='+t2+'.0000000Z',\
                 meta,previter)
     def get_faults(self,veh_id,tdelta=None,previter=None):
